SystemOrganization addCategory: #ConfigurationOfUnits!

Object subclass: #ConfigurationOfUnits
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfUnits'!

!ConfigurationOfUnits commentStamp: '<historical>' prior: 0!
ConfigurationOfUnit !

!ConfigurationOfUnits class methodsFor: 'private' stamp: 'StephaneDucasse 8/31/2013 13:41'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfUnits class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/31/2013 14:03'!
catalogChangeLog

^ '

- 2013-08-31 Version 1.0 - first configuration.

[ [ [ 
	(ConfigurationOfUnit project version: ''1.0'') load.
] ] ]
'! !

!ConfigurationOfUnits class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/31/2013 13:57'!
catalogDescription
	^ 'Units is a simple and powerful library to manage different units.'! !

!ConfigurationOfUnits class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/31/2013 14:00'!
catalogKeyClassesAndExample

^ 'The key classes are

- ==Unit==
Class Unit is the superclass for all other unit classes.
Instances represent units which are attached to numbers; for example
meters (a BaseUnit), meters per second (a CompoundUnit),
joule seconds per liter (a ComplexUnit),  degrees Kelvin (a TemperatureBaseUnit),
degrees Celsius (a TemperutareUnit),  kilohertz (a PrefixedUnit),
and moles of hydrogen (a ModifiedUnit).

==UnitValue== which represents a number with a unit.
'! !

!ConfigurationOfUnits class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/31/2013 13:58'!
catalogKeywords
	^ #(Units Comparison Meter Points)! !

!ConfigurationOfUnits class methodsFor: 'private' stamp: 'StephaneDucasse 8/31/2013 13:41'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfUnits class methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 8/31/2013 13:41'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfUnits class methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 8/31/2013 13:41'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfUnits class methodsFor: 'loading' stamp: 'StephaneDucasse 8/31/2013 13:41'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfUnits class methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 8/31/2013 13:41'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfUnits class methodsFor: 'accessing' stamp: 'StephaneDucasse 8/31/2013 13:41'!
project

	^self new project! !

!ConfigurationOfUnits class methodsFor: 'unloading Metacello' stamp: 'StephaneDucasse 8/31/2013 13:41'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfUnits methodsFor: 'baselines' stamp: 'StephaneDucasse 8/31/2013 13:44'!
baseline01: spec
	<version: '1.0-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/MarcusDenker/Units/main'.
			spec package: 'Units'.
			spec group: 'default' with: #('Units') ]! !

!ConfigurationOfUnits methodsFor: 'accessing' stamp: 'StephaneDucasse 8/31/2013 13:50'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfUnits methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 8/31/2013 13:50'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'pharo2.0.x' version: '1.0'
! !

!ConfigurationOfUnits methodsFor: 'versions' stamp: 'StephaneDucasse 8/31/2013 13:55'!
version01: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #stable;
			author: 'Stephane Ducasse';
			description: 'First configuration of Units'.
		spec 
			package: 'Units' 
			with: 'Units-espin.36'.					
	]! !
